@@ -43,7 +43,7 @@ use warnings;
 use App::CELL qw( $CELL $log $meta $site );
 use App::MFILE::HTTP qw( rest_req );
 use Data::Dumper;
-use File::Temp qw( tempdir );
+use File::Temp qw( tempfile );
 use JSON;
 use LWP::UserAgent;
 use Params::Validate qw(:all);
@@ -52,10 +52,7 @@ use Try::Tiny;
 # methods/attributes not defined in this module will be inherited from:
 use parent 'App::MFILE::WWW::Resource';
 
-our $ua = LWP::UserAgent->new( 
-              cookie_jar => { file => tempdir( CLEANUP => 0 ) }
-          );
-
+our $ualt = {};  # user agent lookup table
 
 
 
@@ -101,11 +98,12 @@ sub is_authorized {
     $log->debug( "Entering " . __PACKAGE__ . "::is_authorized()" );
 
     my $r = $self->request;
-    my $session = $r->{'env'}->{'psgix.session'};
+    my $session = $self->session;
     my $remote_addr = $r->{'env'}->{'REMOTE_ADDR'};
     my $ce;
 
-    #$log->debug( "Session is " . Dumper( $session ) );
+    #$log->debug( "Environment is " . Dumper( $r->{'env'} ) );
+    $log->debug( "Session is " . Dumper( $session ) );
 
     # authorized session
     if ( $ce = $session->{'currentUser'} and
@@ -142,8 +140,37 @@ sub is_authorized {
     }
 
     # unauthorized session
-    # $session = {};
-    return ( $r->method eq 'GET' ) ? 1 : 0;
+    $log->debug( "is_authorized fall-through: " . $r->method . " " . $self->request->path_info );
+    return 1;
+}
+
+
+=head2 ua
+
+Returns the LWP::UserAgent object obtained from the lookup table.
+Creates it first if necessary.
+
+=cut
+
+sub ua {
+    my $self = shift;
+    $log->debug( "Entering " . __PACKAGE__ . "::ua()" );
+    my $id = $self->session_id;
+    $log->debug( "ua: session_id is $id" );
+
+    # already in lookup table
+    if ( exists $ualt->{$id} ) {
+         $log->debug( "Session $id already has a LWP::UserAgent object" );
+         return $ualt->{$id};
+    }
+
+    # not in lookup table yet
+    my $tf = "";
+    ( undef, $tf ) = tempfile();
+    $ualt->{$id} = LWP::UserAgent->new;
+    $ualt->{$id}->cookie_jar({ file => $tf });
+    $log->info("New user agent created with cookies in $tf");
+    return $ualt->{$id};
 }
 
 
@@ -180,7 +207,7 @@ sub process_post {
     $log->debug( "Entering " . __PACKAGE__ . "::process_post()" );
 
     my $r = $self->request;
-    my $session = $r->{'env'}->{'psgix.session'};
+    my $session = $self->session;
     my $ajax = $self->context->{'request_body'};  # request body (Perl string)
 
     if ( ! $ajax ) {
@@ -212,15 +239,15 @@ sub process_post {
 
     # - normal AJAX call (shown for didactic purposes only; App::MFILE::WWW
     #   itself doesn't generate any AJAX calls)
-    $log->debug( "Calling rest_req $method $path" );
+    $log->debug( "Calling rest_req $method $path on session ID " . $self->session_id );
     $session->{'last_seen'} = time;
-    my $rr = rest_req( $ua, {
+    my $rr = rest_req( $self->ua(), {
         server => $site->DOCHAZKA_WWW_BACKEND_URI,
         method => $method,
         path => $path,
         req_body => $body,
     } );
-    # $log->debug( "rest_req returned: " . Dumper( $rr ) );
+    $log->debug( "rest_req returned: " . Dumper( $rr ) );
     my $hr = $rr->{'hr'};
     return $self->_prep_ajax_response( $hr, $rr->{'body'} );
 }
@@ -231,7 +258,7 @@ sub _login_dialog {
     $log->debug( "Entering " . __PACKAGE__ . "::_login_dialog()" );
 
     my $r = $self->request;
-    my $session = $r->{'env'}->{'psgix.session'};
+    my $session = $self->session;
     my $nick = $body->{'nam'};
     my $password = $body->{'pwd'};
     my $standalone = $meta->META_WWW_STANDALONE_MODE;
@@ -240,7 +267,7 @@ sub _login_dialog {
     $log->debug( "DOCHAZKA_WWW_BACKEND_URI is " .  $site->DOCHAZKA_WWW_BACKEND_URI );
 
     my ( $code, $message, $body_json );
-    my $rr = rest_req( $ua, {
+    my $rr = rest_req( $self->ua(), {
         server => $site->DOCHAZKA_WWW_BACKEND_URI,
         nick => $nick,
         password => $password,
@@ -281,7 +308,7 @@ sub _login_dialog {
 sub _logout {
     my ( $self, $body ) = @_;
     $log->debug( "Entering " . __PACKAGE__ . "::_logout()" );
-    my $rr = rest_req( $ua, {
+    my $rr = rest_req( $self->ua(), {
         server => $site->DOCHAZKA_WWW_BACKEND_URI,
         method => 'POST',
         path => 'session/terminate',
@@ -297,6 +324,7 @@ sub _logout {
 
 sub _prep_ajax_response {
     my ( $self, $hr, $body ) = @_;
+    $log->debug( "Entering " . __PACKAGE__ . "::_prep_ajax_response()" );
     my $expurgated_status;
     if ( $hr->is_success ) {
         $expurgated_status = $body;
