@@ -63,6 +63,13 @@ define ([
             'aclProfile': 'passerby',
             'start': dactionStart('drowselectListen')
         });
+        target.push('returnToBrowser', {
+            'name': 'returnToBrowser',
+            'type': 'daction',
+            'menuText': 'returnToBrowser',
+            'aclProfile': 'passerby',
+            'start': dactionStart('returnToBrowser')
+        });
 
         // Employee actions
         target.push('myProfile', {
@@ -72,12 +79,12 @@ define ([
             'aclProfile': 'passerby',
             'start': dactionStart('myProfile')
         });
-        target.push('empProfileUpdate', {
-            'name': 'empProfileUpdate',
+        target.push('empProfileEditSave', {
+            'name': 'empProfileEditSave',
             'type': 'daction',
             'menuText': 'Save changes',
             'aclProfile': 'active',
-            'start': dactionStart('empProfileUpdate')
+            'start': dactionStart('empProfileEditSave')
         });
         target.push('ldapLookupSubmit', {
             'name': 'ldapLookupSubmit',
@@ -126,7 +133,7 @@ define ([
         target.push('actionPrivHistoryEdit', { // read-write
             'name': 'actionPrivHistoryEdit',
             'type': 'daction',
-            'menuText': 'Privilege (status) history EDIT',
+            'menuText': 'Edit',
             'aclProfile': 'admin',
             'start': dactionStart('actionPrivHistoryEdit')
         });
@@ -156,7 +163,7 @@ define ([
         target.push('actionSchedHistoryEdit', { // read-write
             'name': 'actionSchedHistoryEdit',
             'type': 'daction',
-            'menuText': 'Schedule history EDIT',
+            'menuText': 'Edit',
             'aclProfile': 'admin',
             'start': dactionStart('actionSchedHistoryEdit')
         });
@@ -179,7 +186,7 @@ define ([
         target.push('browseAllSchedules', {
             'name': 'browseAllSchedules',
             'type': 'daction',
-            'menuText': 'Browse all schedules',
+            'menuText': 'Browse schedules',
             'aclProfile': 'admin',
             'start': dactionStart('browseAllSchedules')
         });
@@ -197,6 +204,34 @@ define ([
             'aclProfile': 'admin',
             'start': dactionStart('createSchedule')
         });
+        target.push('schedEditFromBrowser', {
+            'name': 'schedEditFromBrowser',
+            'type': 'daction',
+            'menuText': 'Edit',
+            'aclProfile': 'admin',
+            'start': dactionStart('schedEditFromBrowser')
+        });
+        target.push('schedDeleteFromBrowser', {
+            'name': 'schedDeleteFromBrowser',
+            'type': 'daction',
+            'menuText': 'Delete',
+            'aclProfile': 'admin',
+            'start': dactionStart('schedDeleteFromBrowser')
+        });
+        target.push('schedEditSave', {
+            'name': 'schedEditSave',
+            'type': 'daction',
+            'menuText': 'Save changes',
+            'aclProfile': 'active',
+            'start': dactionStart('schedEditSave')
+        });
+        target.push('schedReallyDelete', {
+            'name': 'schedReallyDelete',
+            'type': 'daction',
+            'menuText': 'Yes, I really mean it',
+            'aclProfile': 'admin',
+            'start': dactionStart('schedReallyDelete')
+        });
 
         // Run unit tests
         target.push('unitTests', {
