@@ -81,32 +81,35 @@ define ([
         "drowselectListen": function () {
             start.drowselectListen();
         },
+        "returnToBrowser": function () {
+            start.dbrowserListen();
+        },
 
         // actions triggered from Employee menu
         "myProfile": empLib.myProfile,
-        "empProfileUpdate": empLib.empProfileUpdate,
+        "empProfileEditSave": empLib.empProfileEditSave,
         "ldapLookupSubmit": empLib.ldapLookupSubmit,
         "ldapSync": empLib.ldapSync,
         "ldapSyncSelf": empLib.ldapSyncSelf,
         "actionEmplSearch": empLib.actionEmplSearch,
         "masqEmployee": empLib.masqEmployee,
 
-        // actions triggered from Privhistory menu
+        // actions triggered from Priv (status) menu
         "actionPrivHistory": privLib.actionPrivHistory,
         "actionPrivHistoryEdit": privLib.actionPrivHistoryEdit,
         "privHistorySaveAction": privLib.privHistorySaveAction,
         "privHistoryDeleteAction": privLib.privHistoryDeleteAction,
 
-        // actions triggered from Schedhistory menu
+        // actions triggered from Schedule menu
         "actionSchedHistory": schedHistLib.actionSchedHistory,
         "actionSchedHistoryEdit": schedHistLib.actionSchedHistoryEdit,
         "schedHistorySaveAction": schedHistLib.schedHistorySaveAction,
         "schedHistoryDeleteAction": schedHistLib.schedHistoryDeleteAction,
-
-        // actions triggered from Schedule-admin menu
         "browseAllSchedules": schedLib.browseAllSchedules,
         "actionSchedLookup": schedLib.actionSchedLookup,
         "createSchedule": schedLib.createSchedule,
+        "schedEditSave": schedLib.schedEditSave,
+        "schedReallyDelete": schedLib.schedReallyDelete,
 
         // return to (saved) browser state
         "returnToBrowser": function () {
