@@ -48,7 +48,7 @@ define ([
 ], function (
     currentUser,
     coreLib,
-    lib,
+    appLib,
     empLib,
     restLib,
     schedLib,
@@ -56,7 +56,7 @@ define ([
     target
 ) {
 
-    var entries = lib.entries;
+    var entries = appLib.entries;
     
     return function () {
 
@@ -73,26 +73,28 @@ define ([
             'entriesWrite': [],
             'hook': empLib.getEmployeeProfile,
             'miniMenu': {
-                entries: ['empProfileEditRemark', 'ldapSyncSelf'],
+                entries: ['empProfileEdit', 'ldapSyncSelf'],
                 back: ['Back', 'mainEmpl']
             }
         }); // target.push('empProfile'
 
-        target.push('empProfileEditRemark', {
-            'name': 'empProfileEditRemark',
+        target.push('empProfileEdit', {
+            'name': 'empProfileEdit',
             'type': 'dform',
-            'menuText': 'Edit remark',
-            'title': 'Edit remark',
-            'preamble': null,
+            'menuText': 'Edit',
+            'title': 'Employee profile edit',
+            'preamble': 'Only the remark field can be modified;<br>' +
+                        'All other fields are synced from LDAP',
             'aclProfile': 'admin',
-            'entriesRead': [entries.ePnick, entries.ePfullname],
+            'entriesRead': [entries.ePfullname, entries.ePnick,
+                entries.ePsec_id, entries.ePemail],
             'entriesWrite': [entries.ePremark],
             'hook': empLib.getEmployeeProfile,
             'miniMenu': {
-                entries: ['empProfileUpdate'],
+                entries: ['empProfileEditSave'],
                 back: ['Back', 'empProfile']
             }
-        }); // target.push('empProfileEditRemark'
+        }); // target.push('empProfileEdit'
 
         target.push('ldapLookup', {
             'name': 'ldapLookup',
@@ -212,7 +214,7 @@ define ([
             'menuText': 'Look up schedule by code or ID',
             'title': 'Look up schedule by code or ID',
             'preamble': 'Enter a schedule code or ID',
-            'aclProfile': 'admin',
+            'aclProfile': 'passerby',
             'entriesRead': null,
             'entriesWrite': [entries.sScode, entries.sSid],
             'hook': function () {
@@ -232,7 +234,7 @@ define ([
             'type': 'dform',
             'menuText': 'schedDisplay',
             'title': 'Schedule',
-            'aclProfile': 'admin',
+            'aclProfile': 'passerby',
             'entriesRead': [entries.sDid, entries.sDcode,
                             coreLib.emptyLineEntry, entries.sDmon,
                             entries.sDtue, entries.sDwed, entries.sDthu,
@@ -241,11 +243,68 @@ define ([
             'entriesWrite': null,
             'hook': schedLib.getScheduleForDisplay,
             'miniMenu': {
-                entries: [],
+                entries: ['schedEdit', 'schedDelete'],
                 back: ['Back', 'mainSched']
             }
         }); // target.push('schedDisplay'
 
+        var schedEditObj = {
+                'name': 'schedEdit',
+                'type': 'dform',
+                'menuText': 'Edit',
+                'title': 'Schedule edit',
+                'preamble': 'Only schedule code and remark can be modified<br>' +
+                            'Note: code change will affect <b>all employees</b> with this schedule',
+                'aclProfile': 'admin',
+                'entriesRead': [entries.sDid,
+                                coreLib.emptyLineEntry, entries.sDmon,
+                                entries.sDtue, entries.sDwed, entries.sDthu,
+                                entries.sDfri, entries.sDsat, entries.sDsun],
+                'entriesWrite': [entries.sDcode, entries.ePremark],
+                'hook': schedLib.getScheduleForDisplay,
+                'miniMenu': {
+                    entries: ['schedEditSave'],
+                    back: ['Back', 'schedDisplay']
+                }
+            },
+            schedEditFromBrowserObj = coreLib.shallowCopy(schedEditObj);
+        schedEditFromBrowserObj.name = 'schedEditFromBrowser';
+        schedEditFromBrowserObj.miniMenu.back = ['Back', 'returnToBrowser'];
+        schedEditFromBrowserObj.hook = function () {
+            return coreLib.dbrowserState.set[coreLib.dbrowserState.pos];
+        };
+        target.push('schedEdit', schedEditObj);
+        target.push('schedEditFromBrowser', schedEditFromBrowserObj);
+
+        var schedDeleteObj = {
+                'name': 'schedDelete',
+                'type': 'dform',
+                'menuText': 'Delete',
+                'title': 'Schedule delete',
+                'preamble': 'If you are really sure you want to delete this schedule,<br>' +
+                            'select "Yes, I really mean it" below',
+                'aclProfile': 'admin',
+                'entriesRead': [entries.sDid, entries.sDcode,
+                                coreLib.emptyLineEntry, entries.sDmon,
+                                entries.sDtue, entries.sDwed, entries.sDthu,
+                                entries.sDfri, entries.sDsat, entries.sDsun,
+                                coreLib.emptyLineEntry, entries.ePremark],
+                'entriesWrite': null,
+                'hook': schedLib.getScheduleForDisplay,
+                'miniMenu': {
+                    entries: ['schedReallyDelete'],
+                    back: ['Back', 'schedDisplay']
+                }
+            },
+            schedDeleteFromBrowserObj = coreLib.shallowCopy(schedDeleteObj);
+        schedDeleteFromBrowserObj.name = 'schedDeleteFromBrowser';
+        schedDeleteFromBrowserObj.miniMenu.back = ['Back', 'returnToBrowser'];
+        schedDeleteFromBrowserObj.hook = function () {
+            return coreLib.dbrowserState.set[coreLib.dbrowserState.pos];
+        };
+        target.push('schedDelete', schedDeleteObj);
+        target.push('schedDeleteFromBrowser', schedDeleteFromBrowserObj);
+
         target.push('schedNewBoilerplate', {
             'name': 'schedNewBoilerplate',
             'type': 'dform',
