@@ -70,7 +70,7 @@ define ([
             'menuText': 'Priv (status)',
             'title': 'Priv (status) menu',
             'aclProfile': 'passerby',
-            'entries': ['actionPrivHistory', 'actionPrivHistoryEdit'],
+            'entries': ['actionPrivHistory'],
             'back': 'mainMenu'
         });
 
@@ -79,9 +79,9 @@ define ([
             'type': 'dmenu',
             'menuText': 'Schedule',
             'title': 'Schedule menu',
-            'aclProfile': 'admin',
-            'entries': ['actionSchedHistory', 'actionSchedHistoryEdit',
-                        'browseAllSchedules', 'schedLookup', 'schedNew'],
+            'aclProfile': 'passerby',
+            'entries': ['actionSchedHistory', 'schedLookup',
+                        'browseAllSchedules', 'schedNew'],
             'back': 'mainMenu'
         });
 
