@@ -60,7 +60,7 @@ define ([
             'entries': [entries.pHeffective, entries.pHpriv],
             'hook': lib.holdObject,
             'miniMenu': {
-                entries: null,
+                entries: ['actionPrivHistoryEdit'],
                 back: ['Back', 'mainPriv']
             }
         });
@@ -72,13 +72,12 @@ define ([
             'title': 'Schedule history',
             'preamble': null,
             'aclProfile': 'passerby',
-            'entries': [entries.pHeffective, entries.sDid, entries.sHid],
+            'entries': [entries.pHeffective, entries.sDid, entries.sDcode],
             'hook': lib.holdObject,
             'miniMenu': {
-                entries: null,
+                entries: ['actionSchedHistoryEdit'],
                 back: ['Back', 'mainSched']
-            }
-        });
+            } });
 
     };
     
